export declare const ACTION_PREFIX = "@@kepler.gl/";
/**
 * Kepler.gl action types, can be listened by reducers to perform additional tasks whenever an action is called in kepler.gl
 * @constant
 * @type {Object}
 * @public
 *
 * @example
 * // store.js
 * import {handleActions} from 'redux-actions';
 * import {createStore, combineReducers, applyMiddleware} from 'redux';
 * import {taskMiddleware} from 'react-palm/tasks';
 *
 * import keplerGlReducer from 'kepler.gl/reducers';
 * import {ActionTypes} from 'kepler.gl/actions';
 *
 * const appReducer = handleActions({
 *   // listen on kepler.gl map update action to store a copy of viewport in app state
 *   [ActionTypes.UPDATE_MAP]: (state, action) => ({
 *     ...state,
 *     viewport: action.payload
 *   }),
 * }, {});
 *
 * const reducers = combineReducers({
 *   app: appReducer,
 *   keplerGl: keplerGlReducer
 * });
 *
 * export default createStore(reducers, {}, applyMiddleware(taskMiddleware))
 */
export declare const ActionTypes: {
    REGISTER_ENTRY: string;
    DELETE_ENTRY: string;
    RENAME_ENTRY: string;
    ADD_DATA: string;
    ADD_FILTER: string;
    ADD_LAYER: string;
    APPLY_LAYER_CONFIG: string;
    DUPLICATE_LAYER: string;
    INTERACTION_CONFIG_CHANGE: string;
    LAYER_CONFIG_CHANGE: string;
    LAYER_SET_IS_VALID: string;
    LAYER_VISUAL_CHANNEL_CHANGE: string;
    LAYER_TYPE_CHANGE: string;
    LAYER_VIS_CONFIG_CHANGE: string;
    LAYER_TEXT_LABEL_CHANGE: string;
    LAYER_HOVER: string;
    LAYER_CLICK: string;
    MAP_CLICK: string;
    MOUSE_MOVE: string;
    REMOVE_FILTER: string;
    REMOVE_LAYER: string;
    REMOVE_DATASET: string;
    REORDER_LAYER: string;
    SET_FILTER: string;
    SET_FILTER_ANIMATION_TIME: string;
    SET_FILTER_ANIMATION_TIME_CONFIG: string;
    SET_FILTER_ANIMATION_WINDOW: string;
    SHOW_DATASET_TABLE: string;
    UPDATE_LAYER_BLENDING: string;
    UPDATE_OVERLAY_BLENDING: string;
    UPDATE_VIS_DATA: string;
    RENAME_DATASET: string;
    UPDATE_DATASET_PROPS: string;
    TOGGLE_FILTER_ANIMATION: string;
    UPDATE_FILTER_ANIMATION_SPEED: string;
    PLAY_ANIMATION: string;
    SET_LAYER_ANIMATION_TIME: string;
    SET_LAYER_ANIMATION_TIME_CONFIG: string;
    UPDATE_ANIMATION_SPEED: string;
    UPDATE_LAYER_ANIMATION_SPEED: string;
    TOGGLE_LAYER_ANIMATION: string;
    TOGGLE_LAYER_ANIMATION_CONTROL: string;
    TOGGLE_LAYER_CONFIG_ACTIVE: string;
    SET_FILTER_VIEW: string;
    TOGGLE_FILTER_FEATURE: string;
    TOGGLE_LAYER_FOR_MAP: string;
    SET_FILTER_PLOT: string;
    LOAD_FILES: string;
    LOAD_NEXT_FILE: string;
    LOAD_BATCH_DATA_SUCCESS: string;
    LOAD_FILE_STEP_SUCCESS: string;
    LOAD_FILES_ERR: string;
    LOAD_FILES_SUCCESS: string;
    LAYER_COLOR_UI_CHANGE: string;
    TOGGLE_FEATURE_LAYER: string;
    APPLY_CPU_FILTER: string;
    SET_MAP_INFO: string;
    SORT_TABLE_COLUMN: string;
    PIN_TABLE_COLUMN: string;
    COPY_TABLE_COLUMN: string;
    SET_COLUMN_DISPLAY_FORMAT: string;
    NEXT_FILE_BATCH: string;
    PROCESS_FILE_CONTENT: string;
    UPDATE_TABLE_COLOR: string;
    ADD_EFFECT: string;
    REORDER_EFFECT: string;
    REMOVE_EFFECT: string;
    UPDATE_EFFECT: string;
    UPDATE_MAP: string;
    FIT_BOUNDS: string;
    TOGGLE_PERSPECTIVE: string;
    TOGGLE_FULLSCREEN: string;
    TOGGLE_SPLIT_MAP: string;
    TOGGLE_SPLIT_MAP_VIEWPORT: string;
    MAP_CONFIG_CHANGE: string;
    SET_DEFAULT_MAP_STYLE: string;
    MAP_STYLE_CHANGE: string;
    LOAD_MAP_STYLES: string;
    LOAD_MAP_STYLE_ERR: string;
    INPUT_MAP_STYLE: string;
    LOAD_CUSTOM_MAP_STYLE: string;
    ADD_CUSTOM_MAP_STYLE: string;
    EDIT_CUSTOM_MAP_STYLE: string;
    REMOVE_CUSTOM_MAP_STYLE: string;
    REQUEST_MAP_STYLES: string;
    SET_3D_BUILDING_COLOR: string;
    SET_BACKGROUND_COLOR: string;
    TOGGLE_SIDE_PANEL: string;
    TOGGLE_MODAL: string;
    SHOW_EXPORT_DROPDOWN: string;
    HIDE_EXPORT_DROPDOWN: string;
    TOGGLE_SIDE_PANEL_CLOSE_BUTTON: string;
    OPEN_DELETE_MODAL: string;
    TOGGLE_MAP_CONTROL: string;
    SET_MAP_CONTROL_VISIBILITY: string;
    ADD_NOTIFICATION: string;
    REMOVE_NOTIFICATION: string;
    SET_LOCALE: string;
    TOGGLE_PANEL_LIST_VIEW: string;
    SET_EXPORT_IMAGE_SETTING: string;
    START_EXPORTING_IMAGE: string;
    SET_EXPORT_IMAGE_DATA_URI: string;
    SET_EXPORT_IMAGE_ERROR: string;
    CLEANUP_EXPORT_IMAGE: string;
    SET_EXPORT_VIDEO_SETTING: string;
    SET_EXPORT_SELECTED_DATASET: string;
    SET_EXPORT_DATA_TYPE: string;
    SET_EXPORT_FILTERED: string;
    SET_EXPORT_DATA: string;
    SET_EXPORT_MAP_FORMAT: string;
    SET_USER_MAPBOX_ACCESS_TOKEN: string;
    SET_EXPORT_MAP_HTML_MODE: string;
    SET_EDITOR_MODE: string;
    SET_SELECTED_FEATURE: string;
    INIT: string;
    ADD_DATA_TO_MAP: string;
    RECEIVE_MAP_CONFIG: string;
    RESET_MAP_CONFIG: string;
    REPLACE_DATA_IN_MAP: string;
    SET_FEATURES: string;
    SET_POLYGON_FILTER_LAYER: string;
    DELETE_FEATURE: string;
    TOGGLE_EDITOR_VISIBILITY: string;
    START_SAVE_STORAGE: string;
};
declare const _default: {
    REGISTER_ENTRY: "@@kepler.gl/REGISTER_ENTRY";
    DELETE_ENTRY: "@@kepler.gl/DELETE_ENTRY";
    RENAME_ENTRY: "@@kepler.gl/RENAME_ENTRY";
    ADD_DATA: "@@kepler.gl/ADD_DATA";
    ADD_FILTER: "@@kepler.gl/ADD_FILTER";
    ADD_LAYER: "@@kepler.gl/ADD_LAYER";
    APPLY_LAYER_CONFIG: "@@kepler.gl/APPLY_LAYER_CONFIG";
    DUPLICATE_LAYER: "@@kepler.gl/DUPLICATE_LAYER";
    INTERACTION_CONFIG_CHANGE: "@@kepler.gl/INTERACTION_CONFIG_CHANGE";
    LAYER_CONFIG_CHANGE: "@@kepler.gl/LAYER_CONFIG_CHANGE";
    LAYER_SET_IS_VALID: "@@kepler.gl/LAYER_SET_IS_VALID";
    LAYER_VISUAL_CHANNEL_CHANGE: "@@kepler.gl/LAYER_VISUAL_CHANNEL_CHANGE";
    LAYER_TYPE_CHANGE: "@@kepler.gl/LAYER_TYPE_CHANGE";
    LAYER_VIS_CONFIG_CHANGE: "@@kepler.gl/LAYER_VIS_CONFIG_CHANGE";
    LAYER_TEXT_LABEL_CHANGE: "@@kepler.gl/LAYER_TEXT_LABEL_CHANGE";
    LAYER_HOVER: "@@kepler.gl/LAYER_HOVER";
    LAYER_CLICK: "@@kepler.gl/LAYER_CLICK";
    MAP_CLICK: "@@kepler.gl/MAP_CLICK";
    MOUSE_MOVE: "@@kepler.gl/MOUSE_MOVE";
    REMOVE_FILTER: "@@kepler.gl/REMOVE_FILTER";
    REMOVE_LAYER: "@@kepler.gl/REMOVE_LAYER";
    REMOVE_DATASET: "@@kepler.gl/REMOVE_DATASET";
    REORDER_LAYER: "@@kepler.gl/REORDER_LAYER";
    SET_FILTER: "@@kepler.gl/SET_FILTER";
    SET_FILTER_ANIMATION_TIME: "@@kepler.gl/SET_FILTER_ANIMATION_TIME";
    SET_FILTER_ANIMATION_TIME_CONFIG: "@@kepler.gl/SET_FILTER_ANIMATION_TIME_CONFIG";
    SET_FILTER_ANIMATION_WINDOW: "@@kepler.gl/SET_FILTER_ANIMATION_WINDOW";
    SHOW_DATASET_TABLE: "@@kepler.gl/SHOW_DATASET_TABLE";
    UPDATE_LAYER_BLENDING: "@@kepler.gl/UPDATE_LAYER_BLENDING";
    UPDATE_OVERLAY_BLENDING: "@@kepler.gl/UPDATE_OVERLAY_BLENDING";
    UPDATE_VIS_DATA: "@@kepler.gl/UPDATE_VIS_DATA";
    RENAME_DATASET: "@@kepler.gl/RENAME_DATASET";
    UPDATE_DATASET_PROPS: "@@kepler.gl/UPDATE_DATASET_PROPS";
    TOGGLE_FILTER_ANIMATION: "@@kepler.gl/TOGGLE_FILTER_ANIMATION";
    UPDATE_FILTER_ANIMATION_SPEED: "@@kepler.gl/UPDATE_FILTER_ANIMATION_SPEED";
    PLAY_ANIMATION: "@@kepler.gl/PLAY_ANIMATION";
    SET_LAYER_ANIMATION_TIME: "@@kepler.gl/SET_LAYER_ANIMATION_TIME";
    SET_LAYER_ANIMATION_TIME_CONFIG: "@@kepler.gl/SET_LAYER_ANIMATION_TIME_CONFIG";
    UPDATE_ANIMATION_SPEED: "@@kepler.gl/UPDATE_ANIMATION_SPEED";
    UPDATE_LAYER_ANIMATION_SPEED: "@@kepler.gl/UPDATE_LAYER_ANIMATION_SPEED";
    TOGGLE_LAYER_ANIMATION: "@@kepler.gl/TOGGLE_LAYER_ANIMATION";
    TOGGLE_LAYER_ANIMATION_CONTROL: "@@kepler.gl/TOGGLE_LAYER_ANIMATION_CONTROL";
    TOGGLE_LAYER_CONFIG_ACTIVE: "@@kepler.gl/TOGGLE_LAYER_CONFIG_ACTIVE";
    SET_FILTER_VIEW: "@@kepler.gl/SET_FILTER_VIEW";
    TOGGLE_FILTER_FEATURE: "@@kepler.gl/TOGGLE_FILTER_FEATURE";
    TOGGLE_LAYER_FOR_MAP: "@@kepler.gl/TOGGLE_LAYER_FOR_MAP";
    SET_FILTER_PLOT: "@@kepler.gl/SET_FILTER_PLOT";
    LOAD_FILES: "@@kepler.gl/LOAD_FILES";
    LOAD_NEXT_FILE: "@@kepler.gl/LOAD_NEXT_FILE";
    LOAD_BATCH_DATA_SUCCESS: "@@kepler.gl/LOAD_BATCH_DATA_SUCCESS";
    LOAD_FILE_STEP_SUCCESS: "@@kepler.gl/LOAD_FILE_STEP_SUCCESS";
    LOAD_FILES_ERR: "@@kepler.gl/LOAD_FILES_ERR";
    LOAD_FILES_SUCCESS: "@@kepler.gl/LOAD_FILES_SUCCESS";
    LAYER_COLOR_UI_CHANGE: "@@kepler.gl/LAYER_COLOR_UI_CHANGE";
    TOGGLE_FEATURE_LAYER: "@@kepler.gl/TOGGLE_FEATURE_LAYER";
    APPLY_CPU_FILTER: "@@kepler.gl/APPLY_CPU_FILTER";
    SET_MAP_INFO: "@@kepler.gl/SET_MAP_INFO";
    SORT_TABLE_COLUMN: "@@kepler.gl/SORT_TABLE_COLUMN";
    PIN_TABLE_COLUMN: "@@kepler.gl/PIN_TABLE_COLUMN";
    COPY_TABLE_COLUMN: "@@kepler.gl/COPY_TABLE_COLUMN";
    SET_COLUMN_DISPLAY_FORMAT: "@@kepler.gl/SET_COLUMN_DISPLAY_FORMAT";
    NEXT_FILE_BATCH: "@@kepler.gl/NEXT_FILE_BATCH";
    PROCESS_FILE_CONTENT: "@@kepler.gl/PROCESS_FILE_CONTENT";
    UPDATE_TABLE_COLOR: "@@kepler.gl/UPDATE_TABLE_COLOR";
    ADD_EFFECT: "@@kepler.gl/ADD_EFFECT";
    REORDER_EFFECT: "@@kepler.gl/REORDER_EFFECT";
    REMOVE_EFFECT: "@@kepler.gl/REMOVE_EFFECT";
    UPDATE_EFFECT: "@@kepler.gl/UPDATE_EFFECT";
    UPDATE_MAP: "@@kepler.gl/UPDATE_MAP";
    FIT_BOUNDS: "@@kepler.gl/FIT_BOUNDS";
    TOGGLE_PERSPECTIVE: "@@kepler.gl/TOGGLE_PERSPECTIVE";
    TOGGLE_FULLSCREEN: "@@kepler.gl/TOGGLE_FULLSCREEN";
    TOGGLE_SPLIT_MAP: "@@kepler.gl/TOGGLE_SPLIT_MAP";
    TOGGLE_SPLIT_MAP_VIEWPORT: "@@kepler.gl/TOGGLE_SPLIT_MAP_VIEWPORT";
    MAP_CONFIG_CHANGE: "@@kepler.gl/MAP_CONFIG_CHANGE";
    SET_DEFAULT_MAP_STYLE: "@@kepler.gl/SET_DEFAULT_MAP_STYLE";
    MAP_STYLE_CHANGE: "@@kepler.gl/MAP_STYLE_CHANGE";
    LOAD_MAP_STYLES: "@@kepler.gl/LOAD_MAP_STYLES";
    LOAD_MAP_STYLE_ERR: "@@kepler.gl/LOAD_MAP_STYLE_ERR";
    INPUT_MAP_STYLE: "@@kepler.gl/INPUT_MAP_STYLE";
    LOAD_CUSTOM_MAP_STYLE: "@@kepler.gl/LOAD_CUSTOM_MAP_STYLE";
    ADD_CUSTOM_MAP_STYLE: "@@kepler.gl/ADD_CUSTOM_MAP_STYLE";
    EDIT_CUSTOM_MAP_STYLE: "@@kepler.gl/EDIT_CUSTOM_MAP_STYLE";
    REMOVE_CUSTOM_MAP_STYLE: "@@kepler.gl/REMOVE_CUSTOM_MAP_STYLE";
    REQUEST_MAP_STYLES: "@@kepler.gl/REQUEST_MAP_STYLES";
    SET_3D_BUILDING_COLOR: "@@kepler.gl/SET_3D_BUILDING_COLOR";
    SET_BACKGROUND_COLOR: "@@kepler.gl/SET_BACKGROUND_COLOR";
    TOGGLE_SIDE_PANEL: "@@kepler.gl/TOGGLE_SIDE_PANEL";
    TOGGLE_MODAL: "@@kepler.gl/TOGGLE_MODAL";
    SHOW_EXPORT_DROPDOWN: "@@kepler.gl/SHOW_EXPORT_DROPDOWN";
    HIDE_EXPORT_DROPDOWN: "@@kepler.gl/HIDE_EXPORT_DROPDOWN";
    TOGGLE_SIDE_PANEL_CLOSE_BUTTON: "@@kepler.gl/TOGGLE_SIDE_PANEL_CLOSE_BUTTON";
    OPEN_DELETE_MODAL: "@@kepler.gl/OPEN_DELETE_MODAL";
    TOGGLE_MAP_CONTROL: "@@kepler.gl/TOGGLE_MAP_CONTROL";
    SET_MAP_CONTROL_VISIBILITY: "@@kepler.gl/SET_MAP_CONTROL_VISIBILITY";
    ADD_NOTIFICATION: "@@kepler.gl/ADD_NOTIFICATION";
    REMOVE_NOTIFICATION: "@@kepler.gl/REMOVE_NOTIFICATION";
    SET_LOCALE: "@@kepler.gl/SET_LOCALE";
    TOGGLE_PANEL_LIST_VIEW: "@@kepler.gl/TOGGLE_PANEL_LIST_VIEW";
    SET_EXPORT_IMAGE_SETTING: "@@kepler.gl/SET_EXPORT_IMAGE_SETTING";
    START_EXPORTING_IMAGE: "@@kepler.gl/START_EXPORTING_IMAGE";
    SET_EXPORT_IMAGE_DATA_URI: "@@kepler.gl/SET_EXPORT_IMAGE_DATA_URI";
    SET_EXPORT_IMAGE_ERROR: "@@kepler.gl/SET_EXPORT_IMAGE_ERROR";
    CLEANUP_EXPORT_IMAGE: "@@kepler.gl/CLEANUP_EXPORT_IMAGE";
    SET_EXPORT_VIDEO_SETTING: "@@kepler.gl/SET_EXPORT_VIDEO_SETTING";
    SET_EXPORT_SELECTED_DATASET: "@@kepler.gl/SET_EXPORT_SELECTED_DATASET";
    SET_EXPORT_DATA_TYPE: "@@kepler.gl/SET_EXPORT_DATA_TYPE";
    SET_EXPORT_FILTERED: "@@kepler.gl/SET_EXPORT_FILTERED";
    SET_EXPORT_DATA: "@@kepler.gl/SET_EXPORT_DATA";
    SET_EXPORT_MAP_FORMAT: "@@kepler.gl/SET_EXPORT_MAP_FORMAT";
    SET_USER_MAPBOX_ACCESS_TOKEN: "@@kepler.gl/SET_USER_MAPBOX_ACCESS_TOKEN";
    SET_EXPORT_MAP_HTML_MODE: "@@kepler.gl/SET_EXPORT_MAP_HTML_MODE";
    SET_EDITOR_MODE: "@@kepler.gl/SET_EDITOR_MODE";
    SET_SELECTED_FEATURE: "@@kepler.gl/SET_SELECTED_FEATURE";
    INIT: "@@kepler.gl/INIT";
    ADD_DATA_TO_MAP: "@@kepler.gl/ADD_DATA_TO_MAP";
    RECEIVE_MAP_CONFIG: "@@kepler.gl/RECEIVE_MAP_CONFIG";
    RESET_MAP_CONFIG: "@@kepler.gl/RESET_MAP_CONFIG";
    REPLACE_DATA_IN_MAP: "@@kepler.gl/REPLACE_DATA_IN_MAP";
    SET_FEATURES: "@@kepler.gl/SET_FEATURES";
    SET_POLYGON_FILTER_LAYER: "@@kepler.gl/SET_POLYGON_FILTER_LAYER";
    DELETE_FEATURE: "@@kepler.gl/DELETE_FEATURE";
    TOGGLE_EDITOR_VISIBILITY: "@@kepler.gl/TOGGLE_EDITOR_VISIBILITY";
    START_SAVE_STORAGE: "@@kepler.gl/START_SAVE_STORAGE";
};
export default _default;
